==> distfun-0.3-1-src.zip: distfun/src/cdflib/cumbin.c <==
/* cumbin.f -- translated by f2c (version 20100827). */

#include "cdflib.h"

/* Subroutine */ int cumbin_(double *s, double *xn, double *pr, 
	double *ompr, double *cum, double *ccum)
{
	/* System generated locals */
	double d__1, d__2;

	/* Local variables */

	/* ********************************************************************** */

	/*     SUBROUTINE CUMBIN(S,XN,PBIN,OMPR,CUM,CCUM) */
	/*                    CUmulative BINomial distribution */


	/*                              Function */


	/*     Returns the probability   of 0  to  S  successes in  XN   binomial */
	/*     trials, each of which has a probability of success, PBIN. */


	/*                              Arguments */


	/*     S --> The upper limit of cumulation of the binomial distribution. */
	/*                                                  S is DOUBLE PRECISION */

	/*     XN --> The number of binomial trials. */
	/*                                                  XN is DOUBLE PRECISIO */

	/*     PBIN --> The probability of success in each binomial trial. */
	/*                                                  PBIN is DOUBLE PRECIS */

	/*     OMPR --> 1 - PBIN */
	/*                                                  OMPR is DOUBLE PRECIS */

	/*     CUM <-- Cumulative binomial distribution. */
	/*                                                  CUM is DOUBLE PRECISI */

	/*     CCUM <-- Compliment of Cumulative binomial distribution. */
	/*                                                  CCUM is DOUBLE PRECIS */


	/*                              Method */


	/*     Formula  26.5.24    of   Abramowitz  and    Stegun,  Handbook   of */
	/*     Mathematical   Functions (1966) is   used  to reduce the  binomial */
	/*     distribution  to  the  cumulative    beta distribution. */

	/* ********************************************************************** */
	/*     .. Scalar Arguments .. */
	/*     .. */

	/*     .. */
	/*     .. Executable Statements .. */
	if (! (*s < *xn)) {
		goto L10;
	}
	d__1 = *s + 1.;
	d__2 = *xn - *s;
	cumbet_(pr, ompr, &d__1, &d__2, ccum, cum);
	goto L20;
L10:
	*cum = 1.;
	*ccum = 0.;
L20:
	return 0;
} /* cumbin_ */

==> distfun-0.5-1-src.zip: distfun/src/cdflib/cumbin.c <==
/* cumbin.f -- translated by f2c (version 20100827).
with manual tuning by Michael Baudin (2012)
  */

#include "cdflib.h"
#include "cdflib_private.h" 

/* Subroutine */ int cdflib_cumbin(double x, double xn, double pr, 
	double ompr, double *cum, double *ccum)
{
	/* System generated locals */
	double d__1, d__2;

	/* Local variables */

	/* ********************************************************************** */

	/*     SUBROUTINE CUMBIN(X,XN,PBIN,OMPR,CUM,CCUM) */
	/*                    CUmulative BINomial distribution */


	/*                              Function */


	/*     Returns the probability   of 0  to  X  successes in  XN   binomial */
	/*     trials, each of which has a probability of success, PBIN. */


	/*                              Arguments */


	/*     X --> The upper limit of cumulation of the binomial distribution. */


	/*     XN --> The number of binomial trials. */

	/*     PBIN --> The probability of success in each binomial trial. */

	/*     OMPR --> 1 - PBIN */

	/*     CUM <-- Cumulative binomial distribution. */

	/*     CCUM <-- Compliment of Cumulative binomial distribution. */


	/*                              Method */


	/*     Formula  26.5.24    of   Abramowitz  and    Stegun,  Handbook   of */
	/*     Mathematical   Functions (1966) is   used  to reduce the  binomial */
	/*     distribution  to  the  cumulative    beta distribution. */

	/* ********************************************************************** */

	if (x < xn) {
		d__1 = x + 1.;
		d__2 = xn - x;
		cdflib_cumbet(pr, ompr, d__1, d__2, ccum, cum);
		return 0;
	}
	*cum = 1.;
	*ccum = 0.;
	return 0;
}
